@@ -53,7 +53,7 @@ class HiveRelation(BaseRelation):
         if self.type:
             tracker.track_usage(
                 {
-                    "event_type": "dbt_hive_model_access",
+                    "event_type": tracker.TrackingEventType.MODEL_ACCESS,
                     "model_name": self.render(),
                     "model_type": self.type,
                     "incremental_strategy": "",
@@ -72,7 +72,7 @@ class HiveRelation(BaseRelation):
         if self.type:
             tracker.track_usage(
                 {
-                    "event_type": "dbt_hive_new_incremental",
+                    "event_type": tracker.TrackingEventType.INCREMENTAL,
                     "model_name": self.render(),
                     "model_type": self.type,
                     "incremental_strategy": incremental_strategy,
